Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3563)

Unified Diff: chrome/browser/ui/webui/constrained_web_dialog_delegate_base.cc

Issue 10831407: Kill PropertyBag, switch WebContents to SupportsUserData. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: works Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/constrained_web_dialog_delegate_base.cc
diff --git a/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.cc b/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.cc
index e643841227e1ca2dcfb18b2343ed250e7b90cd59..bfc97d76679d0137ee85b727d5b70dcea5c6984d 100644
--- a/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.cc
+++ b/chrome/browser/ui/webui/constrained_web_dialog_delegate_base.cc
@@ -6,7 +6,6 @@
#include <string>
-#include "base/property_bag.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/ui/constrained_window.h"
#include "chrome/browser/ui/tab_contents/tab_contents.h"
@@ -41,9 +40,8 @@ ConstrainedWebDialogDelegateBase::ConstrainedWebDialogDelegateBase(
} else {
web_contents->SetDelegate(this);
}
- // Set |this| as a property so the ConstrainedWebDialogUI can retrieve it.
- ConstrainedWebDialogUI::GetPropertyAccessor().SetProperty(
- web_contents->GetPropertyBag(), this);
+ // Set |this| as a delegate so the ConstrainedWebDialogUI can retrieve it.
+ ConstrainedWebDialogUI::SetConstrainedDelegate(web_contents, this);
web_contents->GetController().LoadURL(delegate->GetDialogContentURL(),
content::Referrer(),

Powered by Google App Engine
This is Rietveld 408576698